import os.path
from setuptools import setup


exec(open('aws_neuronx_runtime_discovery/version.py').read())


def main():
    version = '2.9'
    libnrt_soname = 'libnrt.so.1'
    libnrt_installation_path = '/opt/aws/neuron/lib'
    soname_path = os.path.join(libnrt_installation_path, libnrt_soname)
    guide_link = 'the Neuron installation guide https://awsdocs-neuron.readthedocs-hosted.com/'
    if not os.path.exists(soname_path):
        raise FileNotFoundError('Could not find Neuron Runtime Library {} (from deb/rpm package aws-neuronx-runtime-lib) in {}. Please check {} to install this library.'.format(soname_path, libnrt_installation_path, guide_link))
    so_realpath = os.path.realpath(soname_path)
    so_basename = os.path.basename(so_realpath)
    _, runtime_version = so_basename.split('libnrt.so.')
    runtime_major_version, *_ = runtime_version.split('.')
    major_version, *_ = __version__.split('.')
    if runtime_major_version != major_version:
        raise FileNotFoundError('Found the Neuron Runtime Library {0} but it is the wrong version. Found version {1} but expected major version {2}. Please check {3} to install the major version {2} of this library'.format(soname_path, runtime_version, major_version, guide_link))

    setup(
        name='aws-neuronx-runtime-discovery',
        version=__version__,
        classifiers=[
            'Development Status :: 5 - Production/Stable',
            'Intended Audience :: Developers',
            'Intended Audience :: Education',
            'Intended Audience :: Science/Research',
            'License :: Other/Proprietary License',
            'Programming Language :: Python :: 3',
            'Topic :: Scientific/Engineering',
            'Topic :: Scientific/Engineering :: Mathematics',
            'Topic :: Scientific/Engineering :: Artificial Intelligence',
            'Topic :: Software Development',
            'Topic :: Software Development :: Libraries',
            'Topic :: Software Development :: Libraries :: Python Modules',
        ],
        keywords='aws neuron neuronx runtime aws-neuronx-runtime-lib',
    )


if __name__ == '__main__':
    main()
